Module: ADesklets::AutoGenerated
- Included in:
- DesktopDrawer
- Defined in:
- lib/adesklets/autobinding.rb
Constant Summary collapse
- TEXT_TO_RIGHT =
constants
0- TEXT_TO_LEFT =
1- TEXT_TO_DOWN =
2- TEXT_TO_UP =
3- TEXT_TO_ANGLE =
4- OP_COPY =
0- OP_ADD =
1- OP_SUBSTRACT =
2- OP_RESHADE =
3- CHANNEL_RED =
0- CHANNEL_GREEN =
1- CHANNEL_BLUE =
2- CHANNEL_ALPHA =
3- WINDOW_UNMANAGED =
0- WINDOW_MANAGED =
1
Instance Method Summary collapse
-
#add_color_to_color_range(*args) ⇒ Object
add_color_to_color_range Add a color to a color range int distance_away.
-
#add_path_to_font_path(*args) ⇒ Object
add_path_to_font_path Add a font path const char *path.
-
#apply_color_modifier(*args) ⇒ Object
apply_color_modifier Apply a color modifier void.
-
#apply_color_modifier_to_rectangle(*args) ⇒ Object
apply_color_modifier_to_rectangle Apply a color modifier int x, int y, int width,int height.
-
#apply_filter(*args) ⇒ Object
apply_filter Apply a dynamic filter const char * script.
-
#blend_image_onto_image(*args) ⇒ Object
blend_image_onto_image Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height, int destination_x,int destination_y, int destination_width,int destination_height.
-
#blend_image_onto_image_at_angle(*args) ⇒ Object
blend_image_onto_image_at_angle Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height,int destination_x,int destination_y, int angle_x,int angle_y.
-
#blend_image_onto_image_skewed(*args) ⇒ Object
blend_image_onto_image_skewed Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height,int destination_x,int destination_y, int h_angle_x,int h_angle_y, int v_angle_x,int v_angle_y.
-
#charset_status(*args) ⇒ Object
charset_status Get charset capabilities void.
-
#clone_image(*args) ⇒ Object
clone_image Create a copy of an image void.
-
#color_modifiers_info(*args) ⇒ Object
color_modifiers_info Get information on all color modifiers void.
-
#color_modifiers_reset_all(*args) ⇒ Object
color_modifiers_reset_all Free all color modifiers void.
-
#color_ranges_info(*args) ⇒ Object
color_ranges_info Get information on all color ranges void.
-
#color_ranges_reset_all(*args) ⇒ Object
color_ranges_reset_all Free all color ranges void.
-
#context_get_angle(*args) ⇒ Object
context_get_angle Get context angle void.
-
#context_get_anti_alias(*args) ⇒ Object
context_get_anti_alias Get context anti alias void.
-
#context_get_blend(*args) ⇒ Object
context_get_blend Get context blending void.
-
#context_get_cliprect(*args) ⇒ Object
context_get_cliprect Get clipping rectange void.
-
#context_get_color(*args) ⇒ Object
context_get_color Get context color void.
-
#context_get_color_modifier(*args) ⇒ Object
context_get_color_modifier Get context color modifier void.
-
#context_get_color_range(*args) ⇒ Object
context_get_color_range Get context color range void.
-
#context_get_direction(*args) ⇒ Object
context_get_direction Get context direction void.
-
#context_get_dither(*args) ⇒ Object
context_get_dither Get context dither void.
-
#context_get_filter(*args) ⇒ Object
context_get_filter Get context filter void.
-
#context_get_font(*args) ⇒ Object
context_get_font Get context font void.
-
#context_get_image(*args) ⇒ Object
context_get_image Get context image void.
-
#context_get_operation(*args) ⇒ Object
context_get_operation Get context operation void.
-
#context_set_angle(*args) ⇒ Object
context_set_angle Set context angle double angle.
-
#context_set_anti_alias(*args) ⇒ Object
context_set_anti_alias Set context anti-alias bool anti_alias.
-
#context_set_blend(*args) ⇒ Object
context_set_blend Set context blending bool blend.
-
#context_set_cliprect(*args) ⇒ Object
context_set_cliprect Set context clipping rectangle int x, int y, int w, int h.
-
#context_set_color(*args) ⇒ Object
context_set_color Set context RGBA color int red, int green, int blue, int alpha.
-
#context_set_color_modifier(*args) ⇒ Object
context_set_color_modifier Set context color modifier [int color_modifier].
-
#context_set_color_range(*args) ⇒ Object
context_set_color_range Set context color range [int color_range].
-
#context_set_direction(*args) ⇒ Object
context_set_direction Set context direction enum DIRECTIONS direction.
-
#context_set_dither(*args) ⇒ Object
context_set_dither Set context dither bool dither.
-
#context_set_filter(*args) ⇒ Object
context_set_filter Set context filter [int filter].
-
#context_set_font(*args) ⇒ Object
context_set_font Set context font [int font].
-
#context_set_image(*args) ⇒ Object
context_set_image Set context image int image.
-
#context_set_operation(*args) ⇒ Object
context_set_operation Set context operation enum OPERATIONS operation.
-
#create_color_modifier(*args) ⇒ Object
create_color_modifier Create a color modifier void.
-
#create_color_range(*args) ⇒ Object
create_color_range Create a color range void.
-
#create_filter(*args) ⇒ Object
create_filter Create a filter void.
-
#create_image(*args) ⇒ Object
create_image Create an image int width, int height.
-
#create_image_using_data(*args) ⇒ Object
create_image_using_data Create an image from data int width, int height,unsigned int * data.
-
#echo(*args) ⇒ Object
echo Echo a string const char * string.
-
#events_get_echo(*args) ⇒ Object
events_get_echo Get events echo status void.
-
#events_get_send_sigusr1(*args) ⇒ Object
events_get_send_sigusr1 Get sending of SIGUSR1 to parent on event void.
-
#events_info(*args) ⇒ Object
events_info Get all caught events void.
-
#filter_constants(*args) ⇒ Object
filter_constants Set filter constants int a, int r, int g, int b.
-
#filter_divisors(*args) ⇒ Object
filter_divisors Set filter divisors int a, int r, int g, int b.
-
#filter_set(*args) ⇒ Object
filter_set Set filter int xoff, int yoff, int a, int r, int g, int b.
-
#filter_set_alpha(*args) ⇒ Object
filter_set_alpha Set filter alpha channel int xoff, int yoff, int a, int r, int g, int b.
-
#filter_set_blue(*args) ⇒ Object
filter_set_blue Set filter blue channel int xoff, int yoff, int a, int r, int g, int b.
-
#filter_set_green(*args) ⇒ Object
filter_set_green Set filter grean channel int xoff, int yoff, int a, int r, int g, int b.
-
#filter_set_red(*args) ⇒ Object
filter_set_red Set filter red channel int xoff, int yoff, int a, int r, int g, int b.
-
#filters_info(*args) ⇒ Object
filters_info Get information on all filters void.
-
#filters_reset_all(*args) ⇒ Object
filters_reset_all Free all filters void.
-
#fonts_info(*args) ⇒ Object
fonts_info Get information on all fonts void.
-
#fonts_reset_all(*args) ⇒ Object
fonts_reset_all Free all fonts void.
-
#free_color_modifier(*args) ⇒ Object
free_color_modifier Free a color modifier int color_modifier.
-
#free_color_range(*args) ⇒ Object
free_color_range Free a color range int color_range.
-
#free_filter(*args) ⇒ Object
free_filter Free a filter int filter.
-
#free_font(*args) ⇒ Object
free_font Free a font int font.
-
#free_image(*args) ⇒ Object
free_image Free an image int image.
-
#get_charset(*args) ⇒ Object
get_charset Get input charset void.
-
#get_color_modifier_tables(*args) ⇒ Object
get_color_modifier_tables Get tables for a color modifier void.
-
#get_color_modifier_value(*args) ⇒ Object
get_color_modifier_value Get a value for a color modifier enum RGBA_TABLES table, int index.
-
#get_id(*args) ⇒ Object
get_id Get current applet identificator void.
-
#get_text_advance(*args) ⇒ Object
get_text_advance Get advance of text const char * text.
-
#get_text_size(*args) ⇒ Object
get_text_size Get size of text const char * text.
-
#help(*args) ⇒ Object
help Display short help about a command [const char * command].
-
#history(*args) ⇒ Object
history List/save commands history [const char * filename].
-
#image_blur(*args) ⇒ Object
image_blur Blur an image int radius.
-
#image_copy_alpha_rectangle_to_image(*args) ⇒ Object
image_copy_alpha_rectangle_to_image Transfert alpha channel int image_source,int x, int y, int width,int height,int destination_x,int destination_y.
-
#image_copy_alpha_to_image(*args) ⇒ Object
image_copy_alpha_to_image Transfert alpha channel int image_source, int x,int y.
-
#image_draw_ellipse(*args) ⇒ Object
image_draw_ellipse Draw an ellipse int xc, int yc, int a, int b.
-
#image_draw_line(*args) ⇒ Object
image_draw_line Draw a line int x1, int y1, int x2, int y2,char make_updates.
-
#image_draw_polygon(*args) ⇒ Object
image_draw_polygon Draw a polygon onto image int poly, unsigned char closed.
-
#image_draw_rectangle(*args) ⇒ Object
image_draw_rectangle Draw a rectangle int x, int y, int width, int height.
-
#image_fill_color_range_rectangle(*args) ⇒ Object
image_fill_color_range_rectangle Draw a gradian filled rectange int x, int y, int width,int height, double angle.
-
#image_fill_ellipse(*args) ⇒ Object
image_fill_ellipse Fill an ellipse int xc, int yc, int a, int b.
-
#image_fill_polygon(*args) ⇒ Object
image_fill_polygon Fill a polygon onto image int poly.
-
#image_fill_rectangle(*args) ⇒ Object
image_fill_rectangle Draw a filled rectangle int x, int y, int width, int height.
-
#image_filter_recurse(*args) ⇒ Object
image_filter_recurse void.
-
#image_flip_diagonal(*args) ⇒ Object
image_flip_diagonal Flip an image diagonally void.
-
#image_flip_horizontal(*args) ⇒ Object
image_flip_horizontal Flip an image horizontally void.
-
#image_flip_vertical(*args) ⇒ Object
image_flip_vertical Flip an image vertically void.
-
#image_get_data(*args) ⇒ Object
image_get_data Get the data of an image void.
-
#image_get_filename(*args) ⇒ Object
image_get_filename Get filename of an image void.
-
#image_get_height(*args) ⇒ Object
image_get_height Get height of an image void.
-
#image_get_width(*args) ⇒ Object
image_get_width Get width of an image void.
-
#image_has_alpha(*args) ⇒ Object
image_has_alpha Get alpha channel setting of an image void.
-
#image_orientate(*args) ⇒ Object
image_orientate Orientate an image int orientation.
-
#image_query_pixel(*args) ⇒ Object
image_query_pixel Query a pixel value int x, int y.
-
#image_set_changes_on_disk(*args) ⇒ Object
image_set_changes_on_disk Set image load time behavior void.
-
#image_set_format(*args) ⇒ Object
image_set_format Set image format const char *format.
-
#image_set_has_alpha(*args) ⇒ Object
image_set_has_alpha Set alpha channel of an image bool has_alpha.
-
#image_sharpen(*args) ⇒ Object
image_sharpen Sharpen an image int radius.
-
#images_info(*args) ⇒ Object
images_info Get information on all images void.
-
#images_reset_all(*args) ⇒ Object
images_reset_all Free all images and refresh foreground void.
-
#list_font_path(*args) ⇒ Object
list_font_path List all fonts path void.
-
#list_fonts(*args) ⇒ Object
list_fonts List all fonts void.
-
#load_font(*args) ⇒ Object
load_font Load a font const char *font_name.
-
#load_image(*args) ⇒ Object
load_image Load an image from disk const char *file.
-
#load_image_without_cache(*args) ⇒ Object
load_image_without_cache Load an image from disk bypassing the cache const char *file.
-
#menu_add_item(*args) ⇒ Object
menu_add_item Add an item to current menu const char * add_item.
-
#menu_add_menu(*args) ⇒ Object
menu_add_menu Add a new menu void.
-
#menu_add_separator(*args) ⇒ Object
menu_add_separator Add a separator to current menu void.
-
#menu_add_submenu(*args) ⇒ Object
menu_add_submenu Add a submenu to current menu const char * submenu.
-
#menu_end_submenu(*args) ⇒ Object
menu_end_submenu End a submenu construction void.
-
#menu_fire(*args) ⇒ Object
menu_fire Fire a given menu int menu.
-
#menu_reset_all(*args) ⇒ Object
menu_reset_all Reset all menus to initial state void.
-
#modify_color_modifier_brightness(*args) ⇒ Object
modify_color_modifier_brightness Modify brightness double brightness_value.
-
#modify_color_modifier_contrast(*args) ⇒ Object
modify_color_modifier_contrast Modify contrast double contrast_value.
-
#modify_color_modifier_gamma(*args) ⇒ Object
modify_color_modifier_gamma Modify gamma correction double gamma_value.
-
#pause(*args) ⇒ Object
pause Freeze the interpreter for debugging [int delay].
-
#ping(*args) ⇒ Object
ping Ping the interpreter void.
-
#play(*args) ⇒ Object
play Play a given macro int beginning, int end.
-
#play_get_abort_on_events(*args) ⇒ Object
play_get_abort_on_events Get replays interuptable status void.
-
#play_set_abort_on_events(*args) ⇒ Object
play_set_abort_on_events Set replays to be interuptable bool abort.
-
#polygon_add_point(*args) ⇒ Object
polygon_add_point Add point to a polygon int poly, int x, int y.
-
#polygon_free(*args) ⇒ Object
polygon_free Free a polygon int poly.
-
#polygon_new(*args) ⇒ Object
polygon_new Create a polygon void.
-
#polygons_info(*args) ⇒ Object
polygons_info Get information on all polygons void.
-
#polygons_reset_all(*args) ⇒ Object
polygons_reset_all Free all polygons void.
-
#quit(*args) ⇒ Object
quit Quit the program void.
-
#remove_path_from_font_path(*args) ⇒ Object
remove_path_from_font_path Remove a font path const char *path.
-
#save_image(*args) ⇒ Object
save_image Save an image to disk const char *filename.
-
#screen_get_depth(*args) ⇒ Object
screen_get_depth Get screen depth void.
-
#screen_get_height(*args) ⇒ Object
screen_get_height Get screen height void.
-
#screen_get_width(*args) ⇒ Object
screen_get_width Get screen width void.
-
#set(*args) ⇒ Object
set Set or unset a textual variable [const * char name, const * char value].
-
#set_charset(*args) ⇒ Object
set_charset Set input charset const char * charset.
-
#set_color_modifier_tables(*args) ⇒ Object
set_color_modifier_tables Set tables for a color modifier unsigned char * table.
-
#set_color_modifier_value(*args) ⇒ Object
set_color_modifier_value Set a value for a color modifier enum RGBA_TABLES table, int index, int value.
-
#start_recording(*args) ⇒ Object
start_recording Start recording a macro void.
-
#stop_recording(*args) ⇒ Object
stop_recording Stop recording the macro void.
-
#text_draw(*args) ⇒ Object
text_draw Draw a text string int x, int y, const char *text.
-
#time_gate(*args) ⇒ Object
time_gate Set a time gate double gate.
-
#unset_all(*args) ⇒ Object
unset_all Unset all defined textual variables void.
-
#version(*args) ⇒ Object
version Get interpreter version void.
-
#window_get_background_grab(*args) ⇒ Object
window_get_background_grab Get automatic grab void.
-
#window_get_background_image(*args) ⇒ Object
window_get_background_image Get background image void.
-
#window_get_managed_status(*args) ⇒ Object
window_get_managed_status Get managed status void.
-
#window_get_transparency(*args) ⇒ Object
window_get_transparency Get automatic transparency void.
-
#window_hide(*args) ⇒ Object
window_hide Unmap the window from the screen void.
-
#window_reset(*args) ⇒ Object
window_reset Reset the window enum WINDOW_MANAGER manager.
-
#window_resize(*args) ⇒ Object
window_resize Resize the window int width, int height.
-
#window_set_background_grab(*args) ⇒ Object
window_set_background_grab Set automatic grab bool grab.
-
#window_set_background_image(*args) ⇒ Object
window_set_background_image Set background image int image.
-
#window_set_transparency(*args) ⇒ Object
window_set_transparency Set automatic transparency bool transparency.
-
#window_show(*args) ⇒ Object
window_show Map the window on the screen void.
-
#x_status(*args) ⇒ Object
x_status Status of connection to X Window server void.
Instance Method Details
#add_color_to_color_range(*args) ⇒ Object
add_color_to_color_range Add a color to a color range int distance_away
308 309 310 |
# File 'lib/adesklets/autobinding.rb', line 308 def add_color_to_color_range(*args) ADesklets::Client.instance.session.command("add_color_to_color_range #{args.join(' ')}") end |
#add_path_to_font_path(*args) ⇒ Object
add_path_to_font_path Add a font path const char *path
476 477 478 |
# File 'lib/adesklets/autobinding.rb', line 476 def add_path_to_font_path(*args) ADesklets::Client.instance.session.command("add_path_to_font_path #{args.join(' ')}") end |
#apply_color_modifier(*args) ⇒ Object
apply_color_modifier Apply a color modifier void
398 399 400 |
# File 'lib/adesklets/autobinding.rb', line 398 def apply_color_modifier(*args) ADesklets::Client.instance.session.command("apply_color_modifier #{args.join(' ')}") end |
#apply_color_modifier_to_rectangle(*args) ⇒ Object
apply_color_modifier_to_rectangle Apply a color modifier int x, int y, int width,int height
404 405 406 |
# File 'lib/adesklets/autobinding.rb', line 404 def apply_color_modifier_to_rectangle(*args) ADesklets::Client.instance.session.command("apply_color_modifier_to_rectangle #{args.join(' ')}") end |
#apply_filter(*args) ⇒ Object
apply_filter Apply a dynamic filter const char * script
332 333 334 |
# File 'lib/adesklets/autobinding.rb', line 332 def apply_filter(*args) ADesklets::Client.instance.session.command("apply_filter #{args.join(' ')}") end |
#blend_image_onto_image(*args) ⇒ Object
blend_image_onto_image Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height, int destination_x,int destination_y, int destination_width,int destination_height
314 315 316 |
# File 'lib/adesklets/autobinding.rb', line 314 def blend_image_onto_image(*args) ADesklets::Client.instance.session.command("blend_image_onto_image #{args.join(' ')}") end |
#blend_image_onto_image_at_angle(*args) ⇒ Object
blend_image_onto_image_at_angle Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height,int destination_x,int destination_y, int angle_x,int angle_y
320 321 322 |
# File 'lib/adesklets/autobinding.rb', line 320 def blend_image_onto_image_at_angle(*args) ADesklets::Client.instance.session.command("blend_image_onto_image_at_angle #{args.join(' ')}") end |
#blend_image_onto_image_skewed(*args) ⇒ Object
blend_image_onto_image_skewed Blend images together int source_image,char merge_alpha, int source_x,int source_y, int source_width,int source_height,int destination_x,int destination_y, int h_angle_x,int h_angle_y, int v_angle_x,int v_angle_y
326 327 328 |
# File 'lib/adesklets/autobinding.rb', line 326 def blend_image_onto_image_skewed(*args) ADesklets::Client.instance.session.command("blend_image_onto_image_skewed #{args.join(' ')}") end |
#charset_status(*args) ⇒ Object
charset_status Get charset capabilities void
968 969 970 |
# File 'lib/adesklets/autobinding.rb', line 968 def charset_status(*args) ADesklets::Client.instance.session.command("charset_status #{args.join(' ')}") end |
#clone_image(*args) ⇒ Object
clone_image Create a copy of an image void
440 441 442 |
# File 'lib/adesklets/autobinding.rb', line 440 def clone_image(*args) ADesklets::Client.instance.session.command("clone_image #{args.join(' ')}") end |
#color_modifiers_info(*args) ⇒ Object
color_modifiers_info Get information on all color modifiers void
584 585 586 |
# File 'lib/adesklets/autobinding.rb', line 584 def color_modifiers_info(*args) ADesklets::Client.instance.session.command("color_modifiers_info #{args.join(' ')}") end |
#color_modifiers_reset_all(*args) ⇒ Object
color_modifiers_reset_all Free all color modifiers void
578 579 580 |
# File 'lib/adesklets/autobinding.rb', line 578 def color_modifiers_reset_all(*args) ADesklets::Client.instance.session.command("color_modifiers_reset_all #{args.join(' ')}") end |
#color_ranges_info(*args) ⇒ Object
color_ranges_info Get information on all color ranges void
572 573 574 |
# File 'lib/adesklets/autobinding.rb', line 572 def color_ranges_info(*args) ADesklets::Client.instance.session.command("color_ranges_info #{args.join(' ')}") end |
#color_ranges_reset_all(*args) ⇒ Object
color_ranges_reset_all Free all color ranges void
566 567 568 |
# File 'lib/adesklets/autobinding.rb', line 566 def color_ranges_reset_all(*args) ADesklets::Client.instance.session.command("color_ranges_reset_all #{args.join(' ')}") end |
#context_get_angle(*args) ⇒ Object
context_get_angle Get context angle void
218 219 220 |
# File 'lib/adesklets/autobinding.rb', line 218 def context_get_angle(*args) ADesklets::Client.instance.session.command("context_get_angle #{args.join(' ')}") end |
#context_get_anti_alias(*args) ⇒ Object
context_get_anti_alias Get context anti alias void
158 159 160 |
# File 'lib/adesklets/autobinding.rb', line 158 def context_get_anti_alias(*args) ADesklets::Client.instance.session.command("context_get_anti_alias #{args.join(' ')}") end |
#context_get_blend(*args) ⇒ Object
context_get_blend Get context blending void
164 165 166 |
# File 'lib/adesklets/autobinding.rb', line 164 def context_get_blend(*args) ADesklets::Client.instance.session.command("context_get_blend #{args.join(' ')}") end |
#context_get_cliprect(*args) ⇒ Object
context_get_cliprect Get clipping rectange void
176 177 178 |
# File 'lib/adesklets/autobinding.rb', line 176 def context_get_cliprect(*args) ADesklets::Client.instance.session.command("context_get_cliprect #{args.join(' ')}") end |
#context_get_color(*args) ⇒ Object
context_get_color Get context color void
212 213 214 |
# File 'lib/adesklets/autobinding.rb', line 212 def context_get_color(*args) ADesklets::Client.instance.session.command("context_get_color #{args.join(' ')}") end |
#context_get_color_modifier(*args) ⇒ Object
context_get_color_modifier Get context color modifier void
200 201 202 |
# File 'lib/adesklets/autobinding.rb', line 200 def context_get_color_modifier(*args) ADesklets::Client.instance.session.command("context_get_color_modifier #{args.join(' ')}") end |
#context_get_color_range(*args) ⇒ Object
context_get_color_range Get context color range void
194 195 196 |
# File 'lib/adesklets/autobinding.rb', line 194 def context_get_color_range(*args) ADesklets::Client.instance.session.command("context_get_color_range #{args.join(' ')}") end |
#context_get_direction(*args) ⇒ Object
context_get_direction Get context direction void
224 225 226 |
# File 'lib/adesklets/autobinding.rb', line 224 def context_get_direction(*args) ADesklets::Client.instance.session.command("context_get_direction #{args.join(' ')}") end |
#context_get_dither(*args) ⇒ Object
context_get_dither Get context dither void
152 153 154 |
# File 'lib/adesklets/autobinding.rb', line 152 def context_get_dither(*args) ADesklets::Client.instance.session.command("context_get_dither #{args.join(' ')}") end |
#context_get_filter(*args) ⇒ Object
context_get_filter Get context filter void
206 207 208 |
# File 'lib/adesklets/autobinding.rb', line 206 def context_get_filter(*args) ADesklets::Client.instance.session.command("context_get_filter #{args.join(' ')}") end |
#context_get_font(*args) ⇒ Object
context_get_font Get context font void
188 189 190 |
# File 'lib/adesklets/autobinding.rb', line 188 def context_get_font(*args) ADesklets::Client.instance.session.command("context_get_font #{args.join(' ')}") end |
#context_get_image(*args) ⇒ Object
context_get_image Get context image void
182 183 184 |
# File 'lib/adesklets/autobinding.rb', line 182 def context_get_image(*args) ADesklets::Client.instance.session.command("context_get_image #{args.join(' ')}") end |
#context_get_operation(*args) ⇒ Object
context_get_operation Get context operation void
170 171 172 |
# File 'lib/adesklets/autobinding.rb', line 170 def context_get_operation(*args) ADesklets::Client.instance.session.command("context_get_operation #{args.join(' ')}") end |
#context_set_angle(*args) ⇒ Object
context_set_angle Set context angle double angle
296 297 298 |
# File 'lib/adesklets/autobinding.rb', line 296 def context_set_angle(*args) ADesklets::Client.instance.session.command("context_set_angle #{args.join(' ')}") end |
#context_set_anti_alias(*args) ⇒ Object
context_set_anti_alias Set context anti-alias bool anti_alias
236 237 238 |
# File 'lib/adesklets/autobinding.rb', line 236 def context_set_anti_alias(*args) ADesklets::Client.instance.session.command("context_set_anti_alias #{args.join(' ')}") end |
#context_set_blend(*args) ⇒ Object
context_set_blend Set context blending bool blend
242 243 244 |
# File 'lib/adesklets/autobinding.rb', line 242 def context_set_blend(*args) ADesklets::Client.instance.session.command("context_set_blend #{args.join(' ')}") end |
#context_set_cliprect(*args) ⇒ Object
context_set_cliprect Set context clipping rectangle int x, int y, int w, int h
254 255 256 |
# File 'lib/adesklets/autobinding.rb', line 254 def context_set_cliprect(*args) ADesklets::Client.instance.session.command("context_set_cliprect #{args.join(' ')}") end |
#context_set_color(*args) ⇒ Object
context_set_color Set context RGBA color int red, int green, int blue, int alpha
290 291 292 |
# File 'lib/adesklets/autobinding.rb', line 290 def context_set_color(*args) ADesklets::Client.instance.session.command("context_set_color #{args.join(' ')}") end |
#context_set_color_modifier(*args) ⇒ Object
context_set_color_modifier Set context color modifier [int color_modifier]
278 279 280 |
# File 'lib/adesklets/autobinding.rb', line 278 def context_set_color_modifier(*args) ADesklets::Client.instance.session.command("context_set_color_modifier #{args.join(' ')}") end |
#context_set_color_range(*args) ⇒ Object
context_set_color_range Set context color range [int color_range]
272 273 274 |
# File 'lib/adesklets/autobinding.rb', line 272 def context_set_color_range(*args) ADesklets::Client.instance.session.command("context_set_color_range #{args.join(' ')}") end |
#context_set_direction(*args) ⇒ Object
context_set_direction Set context direction enum DIRECTIONS direction
302 303 304 |
# File 'lib/adesklets/autobinding.rb', line 302 def context_set_direction(*args) ADesklets::Client.instance.session.command("context_set_direction #{args.join(' ')}") end |
#context_set_dither(*args) ⇒ Object
context_set_dither Set context dither bool dither
230 231 232 |
# File 'lib/adesklets/autobinding.rb', line 230 def context_set_dither(*args) ADesklets::Client.instance.session.command("context_set_dither #{args.join(' ')}") end |
#context_set_filter(*args) ⇒ Object
context_set_filter Set context filter [int filter]
284 285 286 |
# File 'lib/adesklets/autobinding.rb', line 284 def context_set_filter(*args) ADesklets::Client.instance.session.command("context_set_filter #{args.join(' ')}") end |
#context_set_font(*args) ⇒ Object
context_set_font Set context font [int font]
266 267 268 |
# File 'lib/adesklets/autobinding.rb', line 266 def context_set_font(*args) ADesklets::Client.instance.session.command("context_set_font #{args.join(' ')}") end |
#context_set_image(*args) ⇒ Object
context_set_image Set context image int image
260 261 262 |
# File 'lib/adesklets/autobinding.rb', line 260 def context_set_image(*args) ADesklets::Client.instance.session.command("context_set_image #{args.join(' ')}") end |
#context_set_operation(*args) ⇒ Object
context_set_operation Set context operation enum OPERATIONS operation
248 249 250 |
# File 'lib/adesklets/autobinding.rb', line 248 def context_set_operation(*args) ADesklets::Client.instance.session.command("context_set_operation #{args.join(' ')}") end |
#create_color_modifier(*args) ⇒ Object
create_color_modifier Create a color modifier void
512 513 514 |
# File 'lib/adesklets/autobinding.rb', line 512 def create_color_modifier(*args) ADesklets::Client.instance.session.command("create_color_modifier #{args.join(' ')}") end |
#create_color_range(*args) ⇒ Object
create_color_range Create a color range void
488 489 490 |
# File 'lib/adesklets/autobinding.rb', line 488 def create_color_range(*args) ADesklets::Client.instance.session.command("create_color_range #{args.join(' ')}") end |
#create_filter(*args) ⇒ Object
create_filter Create a filter void
500 501 502 |
# File 'lib/adesklets/autobinding.rb', line 500 def create_filter(*args) ADesklets::Client.instance.session.command("create_filter #{args.join(' ')}") end |
#create_image(*args) ⇒ Object
create_image Create an image int width, int height
428 429 430 |
# File 'lib/adesklets/autobinding.rb', line 428 def create_image(*args) ADesklets::Client.instance.session.command("create_image #{args.join(' ')}") end |
#create_image_using_data(*args) ⇒ Object
create_image_using_data Create an image from data int width, int height,unsigned int * data
434 435 436 |
# File 'lib/adesklets/autobinding.rb', line 434 def create_image_using_data(*args) ADesklets::Client.instance.session.command("create_image_using_data #{args.join(' ')}") end |
#echo(*args) ⇒ Object
echo Echo a string const char * string
116 117 118 |
# File 'lib/adesklets/autobinding.rb', line 116 def echo(*args) ADesklets::Client.instance.session.command("echo #{args.join(' ')}") end |
#events_get_echo(*args) ⇒ Object
events_get_echo Get events echo status void
860 861 862 |
# File 'lib/adesklets/autobinding.rb', line 860 def events_get_echo(*args) ADesklets::Client.instance.session.command("events_get_echo #{args.join(' ')}") end |
#events_get_send_sigusr1(*args) ⇒ Object
events_get_send_sigusr1 Get sending of SIGUSR1 to parent on event void
866 867 868 |
# File 'lib/adesklets/autobinding.rb', line 866 def events_get_send_sigusr1(*args) ADesklets::Client.instance.session.command("events_get_send_sigusr1 #{args.join(' ')}") end |
#events_info(*args) ⇒ Object
events_info Get all caught events void
854 855 856 |
# File 'lib/adesklets/autobinding.rb', line 854 def events_info(*args) ADesklets::Client.instance.session.command("events_info #{args.join(' ')}") end |
#filter_constants(*args) ⇒ Object
filter_constants Set filter constants int a, int r, int g, int b
800 801 802 |
# File 'lib/adesklets/autobinding.rb', line 800 def filter_constants(*args) ADesklets::Client.instance.session.command("filter_constants #{args.join(' ')}") end |
#filter_divisors(*args) ⇒ Object
filter_divisors Set filter divisors int a, int r, int g, int b
806 807 808 |
# File 'lib/adesklets/autobinding.rb', line 806 def filter_divisors(*args) ADesklets::Client.instance.session.command("filter_divisors #{args.join(' ')}") end |
#filter_set(*args) ⇒ Object
filter_set Set filter int xoff, int yoff, int a, int r, int g, int b
770 771 772 |
# File 'lib/adesklets/autobinding.rb', line 770 def filter_set(*args) ADesklets::Client.instance.session.command("filter_set #{args.join(' ')}") end |
#filter_set_alpha(*args) ⇒ Object
filter_set_alpha Set filter alpha channel int xoff, int yoff, int a, int r, int g, int b
794 795 796 |
# File 'lib/adesklets/autobinding.rb', line 794 def filter_set_alpha(*args) ADesklets::Client.instance.session.command("filter_set_alpha #{args.join(' ')}") end |
#filter_set_blue(*args) ⇒ Object
filter_set_blue Set filter blue channel int xoff, int yoff, int a, int r, int g, int b
788 789 790 |
# File 'lib/adesklets/autobinding.rb', line 788 def filter_set_blue(*args) ADesklets::Client.instance.session.command("filter_set_blue #{args.join(' ')}") end |
#filter_set_green(*args) ⇒ Object
filter_set_green Set filter grean channel int xoff, int yoff, int a, int r, int g, int b
782 783 784 |
# File 'lib/adesklets/autobinding.rb', line 782 def filter_set_green(*args) ADesklets::Client.instance.session.command("filter_set_green #{args.join(' ')}") end |
#filter_set_red(*args) ⇒ Object
filter_set_red Set filter red channel int xoff, int yoff, int a, int r, int g, int b
776 777 778 |
# File 'lib/adesklets/autobinding.rb', line 776 def filter_set_red(*args) ADesklets::Client.instance.session.command("filter_set_red #{args.join(' ')}") end |
#filters_info(*args) ⇒ Object
filters_info Get information on all filters void
596 597 598 |
# File 'lib/adesklets/autobinding.rb', line 596 def filters_info(*args) ADesklets::Client.instance.session.command("filters_info #{args.join(' ')}") end |
#filters_reset_all(*args) ⇒ Object
filters_reset_all Free all filters void
590 591 592 |
# File 'lib/adesklets/autobinding.rb', line 590 def filters_reset_all(*args) ADesklets::Client.instance.session.command("filters_reset_all #{args.join(' ')}") end |
#fonts_info(*args) ⇒ Object
fonts_info Get information on all fonts void
560 561 562 |
# File 'lib/adesklets/autobinding.rb', line 560 def fonts_info(*args) ADesklets::Client.instance.session.command("fonts_info #{args.join(' ')}") end |
#fonts_reset_all(*args) ⇒ Object
fonts_reset_all Free all fonts void
554 555 556 |
# File 'lib/adesklets/autobinding.rb', line 554 def fonts_reset_all(*args) ADesklets::Client.instance.session.command("fonts_reset_all #{args.join(' ')}") end |
#free_color_modifier(*args) ⇒ Object
free_color_modifier Free a color modifier int color_modifier
518 519 520 |
# File 'lib/adesklets/autobinding.rb', line 518 def free_color_modifier(*args) ADesklets::Client.instance.session.command("free_color_modifier #{args.join(' ')}") end |
#free_color_range(*args) ⇒ Object
free_color_range Free a color range int color_range
494 495 496 |
# File 'lib/adesklets/autobinding.rb', line 494 def free_color_range(*args) ADesklets::Client.instance.session.command("free_color_range #{args.join(' ')}") end |
#free_filter(*args) ⇒ Object
free_filter Free a filter int filter
506 507 508 |
# File 'lib/adesklets/autobinding.rb', line 506 def free_filter(*args) ADesklets::Client.instance.session.command("free_filter #{args.join(' ')}") end |
#free_font(*args) ⇒ Object
free_font Free a font int font
458 459 460 |
# File 'lib/adesklets/autobinding.rb', line 458 def free_font(*args) ADesklets::Client.instance.session.command("free_font #{args.join(' ')}") end |
#free_image(*args) ⇒ Object
free_image Free an image int image
446 447 448 |
# File 'lib/adesklets/autobinding.rb', line 446 def free_image(*args) ADesklets::Client.instance.session.command("free_image #{args.join(' ')}") end |
#get_charset(*args) ⇒ Object
get_charset Get input charset void
956 957 958 |
# File 'lib/adesklets/autobinding.rb', line 956 def get_charset(*args) ADesklets::Client.instance.session.command("get_charset #{args.join(' ')}") end |
#get_color_modifier_tables(*args) ⇒ Object
get_color_modifier_tables Get tables for a color modifier void
374 375 376 |
# File 'lib/adesklets/autobinding.rb', line 374 def get_color_modifier_tables(*args) ADesklets::Client.instance.session.command("get_color_modifier_tables #{args.join(' ')}") end |
#get_color_modifier_value(*args) ⇒ Object
get_color_modifier_value Get a value for a color modifier enum RGBA_TABLES table, int index
386 387 388 |
# File 'lib/adesklets/autobinding.rb', line 386 def get_color_modifier_value(*args) ADesklets::Client.instance.session.command("get_color_modifier_value #{args.join(' ')}") end |
#get_id(*args) ⇒ Object
get_id Get current applet identificator void
92 93 94 |
# File 'lib/adesklets/autobinding.rb', line 92 def get_id(*args) ADesklets::Client.instance.session.command("get_id #{args.join(' ')}") end |
#get_text_advance(*args) ⇒ Object
get_text_advance Get advance of text const char * text
344 345 346 |
# File 'lib/adesklets/autobinding.rb', line 344 def get_text_advance(*args) ADesklets::Client.instance.session.command("get_text_advance #{args.join(' ')}") end |
#get_text_size(*args) ⇒ Object
get_text_size Get size of text const char * text
338 339 340 |
# File 'lib/adesklets/autobinding.rb', line 338 def get_text_size(*args) ADesklets::Client.instance.session.command("get_text_size #{args.join(' ')}") end |
#help(*args) ⇒ Object
help Display short help about a command [const char * command]
68 69 70 |
# File 'lib/adesklets/autobinding.rb', line 68 def help(*args) ADesklets::Client.instance.session.command("help #{args.join(' ')}") end |
#history(*args) ⇒ Object
history List/save commands history [const char * filename]
98 99 100 |
# File 'lib/adesklets/autobinding.rb', line 98 def history(*args) ADesklets::Client.instance.session.command("history #{args.join(' ')}") end |
#image_blur(*args) ⇒ Object
image_blur Blur an image int radius
758 759 760 |
# File 'lib/adesklets/autobinding.rb', line 758 def image_blur(*args) ADesklets::Client.instance.session.command("image_blur #{args.join(' ')}") end |
#image_copy_alpha_rectangle_to_image(*args) ⇒ Object
image_copy_alpha_rectangle_to_image Transfert alpha channel int image_source,int x, int y, int width,int height,int destination_x,int destination_y
716 717 718 |
# File 'lib/adesklets/autobinding.rb', line 716 def image_copy_alpha_rectangle_to_image(*args) ADesklets::Client.instance.session.command("image_copy_alpha_rectangle_to_image #{args.join(' ')}") end |
#image_copy_alpha_to_image(*args) ⇒ Object
image_copy_alpha_to_image Transfert alpha channel int image_source, int x,int y
710 711 712 |
# File 'lib/adesklets/autobinding.rb', line 710 def image_copy_alpha_to_image(*args) ADesklets::Client.instance.session.command("image_copy_alpha_to_image #{args.join(' ')}") end |
#image_draw_ellipse(*args) ⇒ Object
image_draw_ellipse Draw an ellipse int xc, int yc, int a, int b
698 699 700 |
# File 'lib/adesklets/autobinding.rb', line 698 def image_draw_ellipse(*args) ADesklets::Client.instance.session.command("image_draw_ellipse #{args.join(' ')}") end |
#image_draw_line(*args) ⇒ Object
image_draw_line Draw a line int x1, int y1, int x2, int y2,char make_updates
674 675 676 |
# File 'lib/adesklets/autobinding.rb', line 674 def image_draw_line(*args) ADesklets::Client.instance.session.command("image_draw_line #{args.join(' ')}") end |
#image_draw_polygon(*args) ⇒ Object
image_draw_polygon Draw a polygon onto image int poly, unsigned char closed
722 723 724 |
# File 'lib/adesklets/autobinding.rb', line 722 def image_draw_polygon(*args) ADesklets::Client.instance.session.command("image_draw_polygon #{args.join(' ')}") end |
#image_draw_rectangle(*args) ⇒ Object
image_draw_rectangle Draw a rectangle int x, int y, int width, int height
680 681 682 |
# File 'lib/adesklets/autobinding.rb', line 680 def image_draw_rectangle(*args) ADesklets::Client.instance.session.command("image_draw_rectangle #{args.join(' ')}") end |
#image_fill_color_range_rectangle(*args) ⇒ Object
image_fill_color_range_rectangle Draw a gradian filled rectange int x, int y, int width,int height, double angle
692 693 694 |
# File 'lib/adesklets/autobinding.rb', line 692 def image_fill_color_range_rectangle(*args) ADesklets::Client.instance.session.command("image_fill_color_range_rectangle #{args.join(' ')}") end |
#image_fill_ellipse(*args) ⇒ Object
image_fill_ellipse Fill an ellipse int xc, int yc, int a, int b
704 705 706 |
# File 'lib/adesklets/autobinding.rb', line 704 def image_fill_ellipse(*args) ADesklets::Client.instance.session.command("image_fill_ellipse #{args.join(' ')}") end |
#image_fill_polygon(*args) ⇒ Object
image_fill_polygon Fill a polygon onto image int poly
728 729 730 |
# File 'lib/adesklets/autobinding.rb', line 728 def image_fill_polygon(*args) ADesklets::Client.instance.session.command("image_fill_polygon #{args.join(' ')}") end |
#image_fill_rectangle(*args) ⇒ Object
image_fill_rectangle Draw a filled rectangle int x, int y, int width, int height
686 687 688 |
# File 'lib/adesklets/autobinding.rb', line 686 def image_fill_rectangle(*args) ADesklets::Client.instance.session.command("image_fill_rectangle #{args.join(' ')}") end |
#image_filter_recurse(*args) ⇒ Object
image_filter_recurse void
668 669 670 |
# File 'lib/adesklets/autobinding.rb', line 668 def image_filter_recurse(*args) ADesklets::Client.instance.session.command("image_filter_recurse #{args.join(' ')}") end |
#image_flip_diagonal(*args) ⇒ Object
image_flip_diagonal Flip an image diagonally void
746 747 748 |
# File 'lib/adesklets/autobinding.rb', line 746 def image_flip_diagonal(*args) ADesklets::Client.instance.session.command("image_flip_diagonal #{args.join(' ')}") end |
#image_flip_horizontal(*args) ⇒ Object
image_flip_horizontal Flip an image horizontally void
734 735 736 |
# File 'lib/adesklets/autobinding.rb', line 734 def image_flip_horizontal(*args) ADesklets::Client.instance.session.command("image_flip_horizontal #{args.join(' ')}") end |
#image_flip_vertical(*args) ⇒ Object
image_flip_vertical Flip an image vertically void
740 741 742 |
# File 'lib/adesklets/autobinding.rb', line 740 def image_flip_vertical(*args) ADesklets::Client.instance.session.command("image_flip_vertical #{args.join(' ')}") end |
#image_get_data(*args) ⇒ Object
image_get_data Get the data of an image void
638 639 640 |
# File 'lib/adesklets/autobinding.rb', line 638 def image_get_data(*args) ADesklets::Client.instance.session.command("image_get_data #{args.join(' ')}") end |
#image_get_filename(*args) ⇒ Object
image_get_filename Get filename of an image void
632 633 634 |
# File 'lib/adesklets/autobinding.rb', line 632 def image_get_filename(*args) ADesklets::Client.instance.session.command("image_get_filename #{args.join(' ')}") end |
#image_get_height(*args) ⇒ Object
image_get_height Get height of an image void
626 627 628 |
# File 'lib/adesklets/autobinding.rb', line 626 def image_get_height(*args) ADesklets::Client.instance.session.command("image_get_height #{args.join(' ')}") end |
#image_get_width(*args) ⇒ Object
image_get_width Get width of an image void
620 621 622 |
# File 'lib/adesklets/autobinding.rb', line 620 def image_get_width(*args) ADesklets::Client.instance.session.command("image_get_width #{args.join(' ')}") end |
#image_has_alpha(*args) ⇒ Object
image_has_alpha Get alpha channel setting of an image void
614 615 616 |
# File 'lib/adesklets/autobinding.rb', line 614 def image_has_alpha(*args) ADesklets::Client.instance.session.command("image_has_alpha #{args.join(' ')}") end |
#image_orientate(*args) ⇒ Object
image_orientate Orientate an image int orientation
752 753 754 |
# File 'lib/adesklets/autobinding.rb', line 752 def image_orientate(*args) ADesklets::Client.instance.session.command("image_orientate #{args.join(' ')}") end |
#image_query_pixel(*args) ⇒ Object
image_query_pixel Query a pixel value int x, int y
644 645 646 |
# File 'lib/adesklets/autobinding.rb', line 644 def image_query_pixel(*args) ADesklets::Client.instance.session.command("image_query_pixel #{args.join(' ')}") end |
#image_set_changes_on_disk(*args) ⇒ Object
image_set_changes_on_disk Set image load time behavior void
656 657 658 |
# File 'lib/adesklets/autobinding.rb', line 656 def image_set_changes_on_disk(*args) ADesklets::Client.instance.session.command("image_set_changes_on_disk #{args.join(' ')}") end |
#image_set_format(*args) ⇒ Object
image_set_format Set image format const char *format
662 663 664 |
# File 'lib/adesklets/autobinding.rb', line 662 def image_set_format(*args) ADesklets::Client.instance.session.command("image_set_format #{args.join(' ')}") end |
#image_set_has_alpha(*args) ⇒ Object
image_set_has_alpha Set alpha channel of an image bool has_alpha
650 651 652 |
# File 'lib/adesklets/autobinding.rb', line 650 def image_set_has_alpha(*args) ADesklets::Client.instance.session.command("image_set_has_alpha #{args.join(' ')}") end |
#image_sharpen(*args) ⇒ Object
image_sharpen Sharpen an image int radius
764 765 766 |
# File 'lib/adesklets/autobinding.rb', line 764 def image_sharpen(*args) ADesklets::Client.instance.session.command("image_sharpen #{args.join(' ')}") end |
#images_info(*args) ⇒ Object
images_info Get information on all images void
548 549 550 |
# File 'lib/adesklets/autobinding.rb', line 548 def images_info(*args) ADesklets::Client.instance.session.command("images_info #{args.join(' ')}") end |
#images_reset_all(*args) ⇒ Object
images_reset_all Free all images and refresh foreground void
542 543 544 |
# File 'lib/adesklets/autobinding.rb', line 542 def images_reset_all(*args) ADesklets::Client.instance.session.command("images_reset_all #{args.join(' ')}") end |
#list_font_path(*args) ⇒ Object
list_font_path List all fonts path void
470 471 472 |
# File 'lib/adesklets/autobinding.rb', line 470 def list_font_path(*args) ADesklets::Client.instance.session.command("list_font_path #{args.join(' ')}") end |
#list_fonts(*args) ⇒ Object
list_fonts List all fonts void
464 465 466 |
# File 'lib/adesklets/autobinding.rb', line 464 def list_fonts(*args) ADesklets::Client.instance.session.command("list_fonts #{args.join(' ')}") end |
#load_font(*args) ⇒ Object
load_font Load a font const char *font_name
452 453 454 |
# File 'lib/adesklets/autobinding.rb', line 452 def load_font(*args) ADesklets::Client.instance.session.command("load_font #{args.join(' ')}") end |
#load_image(*args) ⇒ Object
load_image Load an image from disk const char *file
416 417 418 |
# File 'lib/adesklets/autobinding.rb', line 416 def load_image(*args) ADesklets::Client.instance.session.command("load_image #{args.join(' ')}") end |
#load_image_without_cache(*args) ⇒ Object
load_image_without_cache Load an image from disk bypassing the cache const char *file
410 411 412 |
# File 'lib/adesklets/autobinding.rb', line 410 def load_image_without_cache(*args) ADesklets::Client.instance.session.command("load_image_without_cache #{args.join(' ')}") end |
#menu_add_item(*args) ⇒ Object
menu_add_item Add an item to current menu const char * add_item
836 837 838 |
# File 'lib/adesklets/autobinding.rb', line 836 def (*args) ADesklets::Client.instance.session.command("menu_add_item #{args.join(' ')}") end |
#menu_add_menu(*args) ⇒ Object
menu_add_menu Add a new menu void
824 825 826 |
# File 'lib/adesklets/autobinding.rb', line 824 def (*args) ADesklets::Client.instance.session.command("menu_add_menu #{args.join(' ')}") end |
#menu_add_separator(*args) ⇒ Object
menu_add_separator Add a separator to current menu void
842 843 844 |
# File 'lib/adesklets/autobinding.rb', line 842 def (*args) ADesklets::Client.instance.session.command("menu_add_separator #{args.join(' ')}") end |
#menu_add_submenu(*args) ⇒ Object
menu_add_submenu Add a submenu to current menu const char * submenu
830 831 832 |
# File 'lib/adesklets/autobinding.rb', line 830 def (*args) ADesklets::Client.instance.session.command("menu_add_submenu #{args.join(' ')}") end |
#menu_end_submenu(*args) ⇒ Object
menu_end_submenu End a submenu construction void
848 849 850 |
# File 'lib/adesklets/autobinding.rb', line 848 def (*args) ADesklets::Client.instance.session.command("menu_end_submenu #{args.join(' ')}") end |
#menu_fire(*args) ⇒ Object
menu_fire Fire a given menu int menu
812 813 814 |
# File 'lib/adesklets/autobinding.rb', line 812 def (*args) ADesklets::Client.instance.session.command("menu_fire #{args.join(' ')}") end |
#menu_reset_all(*args) ⇒ Object
menu_reset_all Reset all menus to initial state void
818 819 820 |
# File 'lib/adesklets/autobinding.rb', line 818 def (*args) ADesklets::Client.instance.session.command("menu_reset_all #{args.join(' ')}") end |
#modify_color_modifier_brightness(*args) ⇒ Object
modify_color_modifier_brightness Modify brightness double brightness_value
362 363 364 |
# File 'lib/adesklets/autobinding.rb', line 362 def modify_color_modifier_brightness(*args) ADesklets::Client.instance.session.command("modify_color_modifier_brightness #{args.join(' ')}") end |
#modify_color_modifier_contrast(*args) ⇒ Object
modify_color_modifier_contrast Modify contrast double contrast_value
368 369 370 |
# File 'lib/adesklets/autobinding.rb', line 368 def modify_color_modifier_contrast(*args) ADesklets::Client.instance.session.command("modify_color_modifier_contrast #{args.join(' ')}") end |
#modify_color_modifier_gamma(*args) ⇒ Object
modify_color_modifier_gamma Modify gamma correction double gamma_value
356 357 358 |
# File 'lib/adesklets/autobinding.rb', line 356 def modify_color_modifier_gamma(*args) ADesklets::Client.instance.session.command("modify_color_modifier_gamma #{args.join(' ')}") end |
#pause(*args) ⇒ Object
pause Freeze the interpreter for debugging [int delay]
80 81 82 |
# File 'lib/adesklets/autobinding.rb', line 80 def pause(*args) ADesklets::Client.instance.session.command("pause #{args.join(' ')}") end |
#ping(*args) ⇒ Object
ping Ping the interpreter void
74 75 76 |
# File 'lib/adesklets/autobinding.rb', line 74 def ping(*args) ADesklets::Client.instance.session.command("ping #{args.join(' ')}") end |
#play(*args) ⇒ Object
play Play a given macro int beginning, int end
146 147 148 |
# File 'lib/adesklets/autobinding.rb', line 146 def play(*args) ADesklets::Client.instance.session.command("play #{args.join(' ')}") end |
#play_get_abort_on_events(*args) ⇒ Object
play_get_abort_on_events Get replays interuptable status void
134 135 136 |
# File 'lib/adesklets/autobinding.rb', line 134 def play_get_abort_on_events(*args) ADesklets::Client.instance.session.command("play_get_abort_on_events #{args.join(' ')}") end |
#play_set_abort_on_events(*args) ⇒ Object
play_set_abort_on_events Set replays to be interuptable bool abort
140 141 142 |
# File 'lib/adesklets/autobinding.rb', line 140 def play_set_abort_on_events(*args) ADesklets::Client.instance.session.command("play_set_abort_on_events #{args.join(' ')}") end |
#polygon_add_point(*args) ⇒ Object
polygon_add_point Add point to a polygon int poly, int x, int y
536 537 538 |
# File 'lib/adesklets/autobinding.rb', line 536 def polygon_add_point(*args) ADesklets::Client.instance.session.command("polygon_add_point #{args.join(' ')}") end |
#polygon_free(*args) ⇒ Object
polygon_free Free a polygon int poly
530 531 532 |
# File 'lib/adesklets/autobinding.rb', line 530 def polygon_free(*args) ADesklets::Client.instance.session.command("polygon_free #{args.join(' ')}") end |
#polygon_new(*args) ⇒ Object
polygon_new Create a polygon void
524 525 526 |
# File 'lib/adesklets/autobinding.rb', line 524 def polygon_new(*args) ADesklets::Client.instance.session.command("polygon_new #{args.join(' ')}") end |
#polygons_info(*args) ⇒ Object
polygons_info Get information on all polygons void
608 609 610 |
# File 'lib/adesklets/autobinding.rb', line 608 def polygons_info(*args) ADesklets::Client.instance.session.command("polygons_info #{args.join(' ')}") end |
#polygons_reset_all(*args) ⇒ Object
polygons_reset_all Free all polygons void
602 603 604 |
# File 'lib/adesklets/autobinding.rb', line 602 def polygons_reset_all(*args) ADesklets::Client.instance.session.command("polygons_reset_all #{args.join(' ')}") end |
#quit(*args) ⇒ Object
quit Quit the program void
980 981 982 |
# File 'lib/adesklets/autobinding.rb', line 980 def quit(*args) ADesklets::Client.instance.session.command("quit #{args.join(' ')}") end |
#remove_path_from_font_path(*args) ⇒ Object
remove_path_from_font_path Remove a font path const char *path
482 483 484 |
# File 'lib/adesklets/autobinding.rb', line 482 def remove_path_from_font_path(*args) ADesklets::Client.instance.session.command("remove_path_from_font_path #{args.join(' ')}") end |
#save_image(*args) ⇒ Object
save_image Save an image to disk const char *filename
422 423 424 |
# File 'lib/adesklets/autobinding.rb', line 422 def save_image(*args) ADesklets::Client.instance.session.command("save_image #{args.join(' ')}") end |
#screen_get_depth(*args) ⇒ Object
screen_get_depth Get screen depth void
950 951 952 |
# File 'lib/adesklets/autobinding.rb', line 950 def screen_get_depth(*args) ADesklets::Client.instance.session.command("screen_get_depth #{args.join(' ')}") end |
#screen_get_height(*args) ⇒ Object
screen_get_height Get screen height void
944 945 946 |
# File 'lib/adesklets/autobinding.rb', line 944 def screen_get_height(*args) ADesklets::Client.instance.session.command("screen_get_height #{args.join(' ')}") end |
#screen_get_width(*args) ⇒ Object
screen_get_width Get screen width void
938 939 940 |
# File 'lib/adesklets/autobinding.rb', line 938 def screen_get_width(*args) ADesklets::Client.instance.session.command("screen_get_width #{args.join(' ')}") end |
#set(*args) ⇒ Object
set Set or unset a textual variable [const * char name, const * char value]
104 105 106 |
# File 'lib/adesklets/autobinding.rb', line 104 def set(*args) ADesklets::Client.instance.session.command("set #{args.join(' ')}") end |
#set_charset(*args) ⇒ Object
set_charset Set input charset const char * charset
962 963 964 |
# File 'lib/adesklets/autobinding.rb', line 962 def set_charset(*args) ADesklets::Client.instance.session.command("set_charset #{args.join(' ')}") end |
#set_color_modifier_tables(*args) ⇒ Object
set_color_modifier_tables Set tables for a color modifier unsigned char * table
380 381 382 |
# File 'lib/adesklets/autobinding.rb', line 380 def set_color_modifier_tables(*args) ADesklets::Client.instance.session.command("set_color_modifier_tables #{args.join(' ')}") end |
#set_color_modifier_value(*args) ⇒ Object
set_color_modifier_value Set a value for a color modifier enum RGBA_TABLES table, int index, int value
392 393 394 |
# File 'lib/adesklets/autobinding.rb', line 392 def set_color_modifier_value(*args) ADesklets::Client.instance.session.command("set_color_modifier_value #{args.join(' ')}") end |
#start_recording(*args) ⇒ Object
start_recording Start recording a macro void
122 123 124 |
# File 'lib/adesklets/autobinding.rb', line 122 def start_recording(*args) ADesklets::Client.instance.session.command("start_recording #{args.join(' ')}") end |
#stop_recording(*args) ⇒ Object
stop_recording Stop recording the macro void
128 129 130 |
# File 'lib/adesklets/autobinding.rb', line 128 def stop_recording(*args) ADesklets::Client.instance.session.command("stop_recording #{args.join(' ')}") end |
#text_draw(*args) ⇒ Object
text_draw Draw a text string int x, int y, const char *text
350 351 352 |
# File 'lib/adesklets/autobinding.rb', line 350 def text_draw(*args) ADesklets::Client.instance.session.command("text_draw #{args.join(' ')}") end |
#time_gate(*args) ⇒ Object
time_gate Set a time gate double gate
62 63 64 |
# File 'lib/adesklets/autobinding.rb', line 62 def time_gate(*args) ADesklets::Client.instance.session.command("time_gate #{args.join(' ')}") end |
#unset_all(*args) ⇒ Object
unset_all Unset all defined textual variables void
110 111 112 |
# File 'lib/adesklets/autobinding.rb', line 110 def unset_all(*args) ADesklets::Client.instance.session.command("unset_all #{args.join(' ')}") end |
#version(*args) ⇒ Object
version Get interpreter version void
86 87 88 |
# File 'lib/adesklets/autobinding.rb', line 86 def version(*args) ADesklets::Client.instance.session.command("version #{args.join(' ')}") end |
#window_get_background_grab(*args) ⇒ Object
window_get_background_grab Get automatic grab void
902 903 904 |
# File 'lib/adesklets/autobinding.rb', line 902 def window_get_background_grab(*args) ADesklets::Client.instance.session.command("window_get_background_grab #{args.join(' ')}") end |
#window_get_background_image(*args) ⇒ Object
window_get_background_image Get background image void
908 909 910 |
# File 'lib/adesklets/autobinding.rb', line 908 def window_get_background_image(*args) ADesklets::Client.instance.session.command("window_get_background_image #{args.join(' ')}") end |
#window_get_managed_status(*args) ⇒ Object
window_get_managed_status Get managed status void
914 915 916 |
# File 'lib/adesklets/autobinding.rb', line 914 def window_get_managed_status(*args) ADesklets::Client.instance.session.command("window_get_managed_status #{args.join(' ')}") end |
#window_get_transparency(*args) ⇒ Object
window_get_transparency Get automatic transparency void
896 897 898 |
# File 'lib/adesklets/autobinding.rb', line 896 def window_get_transparency(*args) ADesklets::Client.instance.session.command("window_get_transparency #{args.join(' ')}") end |
#window_hide(*args) ⇒ Object
window_hide Unmap the window from the screen void
884 885 886 |
# File 'lib/adesklets/autobinding.rb', line 884 def window_hide(*args) ADesklets::Client.instance.session.command("window_hide #{args.join(' ')}") end |
#window_reset(*args) ⇒ Object
window_reset Reset the window enum WINDOW_MANAGER manager
872 873 874 |
# File 'lib/adesklets/autobinding.rb', line 872 def window_reset(*args) ADesklets::Client.instance.session.command("window_reset #{args.join(' ')}") end |
#window_resize(*args) ⇒ Object
window_resize Resize the window int width, int height
890 891 892 |
# File 'lib/adesklets/autobinding.rb', line 890 def window_resize(*args) ADesklets::Client.instance.session.command("window_resize #{args.join(' ')}") end |
#window_set_background_grab(*args) ⇒ Object
window_set_background_grab Set automatic grab bool grab
926 927 928 |
# File 'lib/adesklets/autobinding.rb', line 926 def window_set_background_grab(*args) ADesklets::Client.instance.session.command("window_set_background_grab #{args.join(' ')}") end |
#window_set_background_image(*args) ⇒ Object
window_set_background_image Set background image int image
932 933 934 |
# File 'lib/adesklets/autobinding.rb', line 932 def window_set_background_image(*args) ADesklets::Client.instance.session.command("window_set_background_image #{args.join(' ')}") end |
#window_set_transparency(*args) ⇒ Object
window_set_transparency Set automatic transparency bool transparency
920 921 922 |
# File 'lib/adesklets/autobinding.rb', line 920 def window_set_transparency(*args) ADesklets::Client.instance.session.command("window_set_transparency #{args.join(' ')}") end |